package com.srs.comprehensive.mapper;

import java.util.List;

import com.srs.comprehensive.domain.SrsEducationExperience;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;

/**
 * 教育经历
Mapper接口
 *
 * @author srs
 * @date 2024-04-08
 */
public interface SrsEducationExperienceMapper extends BaseMapper<SrsEducationExperience> {
    /**
     * 查询教育经历

     *
     * @param eduId 教育经历
主键
     * @return 教育经历

     */
    public SrsEducationExperience selectSrsEducationExperienceByEduId(Long eduId);

    /**
     * 查询教育经历
列表
     *
     * @param srsEducationExperience 教育经历

     * @return 教育经历
集合
     */
    List<SrsEducationExperience> selectSrsEducationExperienceList(SrsEducationExperience srsEducationExperience);

    /**
     * 新增教育经历

     *
     * @param srsEducationExperience 教育经历

     * @return 结果
     */
    int insertSrsEducationExperience(SrsEducationExperience srsEducationExperience);

    /**
     * 修改教育经历

     *
     * @param srsEducationExperience 教育经历

     * @return 结果
     */
    int updateSrsEducationExperience(SrsEducationExperience srsEducationExperience);

    /**
     * 删除教育经历

     *
     * @param eduId 教育经历
主键
     * @return 结果
     */
    int deleteSrsEducationExperienceByEduId(Long eduId);

    /**
     * 批量删除教育经历

     *
     * @param eduIds 需要删除的数据主键集合
     * @return 结果
     */
    int deleteSrsEducationExperienceByEduIds(Long[] eduIds);
}
